@@ -14,7 +14,7 @@ use std::str;
 ///
 /// [`DEFAULT_CONFIG`]: crate::DEFAULT_CONFIG
 #[derive(Debug, RustEmbed)]
-#[folder = "../config/"]
+#[folder = "config/"]
 pub struct EmbeddedConfig;
 
 impl EmbeddedConfig {
